:title: Title Name
:author: Author Name
:date: This is the date
:fontsize: 12pt
:margin: 2.0in
:linespread: 1.3
:usepackages: xcolor

\color{blue}

This text should be blue.

\color{black}

This text should not be.